@@ -48,5 +48,5 @@ class Translator:
             fname=self.font_path)
         pdf.set_font('SUN7_8_1210', '', size=14)
         pdf.add_page()
-        pdf.write(txt=text)
+        pdf.multi_cell(w=0, txt=text)
         pdf.output(save_file)
